@@ -2,11 +2,11 @@ package Compress::Snappy;
 
 use strict;
 use warnings;
-use parent qw(Exporter);
 
+use Exporter qw(import);
 use XSLoader;
 
-our $VERSION    = '0.20';
+our $VERSION    = '0.21';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
